set more off
*note change directory below according to location of input files
cd "H:\Reserve Requirement\Stata\FinalJMCB_MS11_463"


*************************************************
*Figures for All Banks 
*************************************************

*Also to run some charts on BDL monthly data
*This data is sourced from BDL that reports aggregate commercial banks balance sheets since dec 1997 (and also reports its own balance sheet)
*Note: Raw BDL data is reported in billions of LBP

insheet using bdl.csv
gen date = ym(year,month)
format %tm date
tsset date
order date
gen a_loan_share_ll = a_loan_ll/a_loan
gen l_deposit_share_ll = (l_deposit_sight_ll+l_deposit_timesaving_ll)/l_deposit
gen reserve_toa = a_reserve/a_total
gen loan_toa = a_loan/a_total
gen deposit_toa = l_deposit/a_total
foreach x in a_loan a_loan_ll a_loan_fc 	{
	gen ln_`x' = log(`x')
	gen D12ln_`x' = ln_`x' - L12.ln_`x'
}

set scheme economist

	
line reserve_toa date if date <= m(2004m12) & date>=m(1997m12), clwidth(medthick) xline(497) xline(501, lcolor(khaki)) /*
	*/ legend(region(fcolor(gs16)) col(1)) xlabel(461 479 497 515 533 ,labsize(*0.75))  /*
	*/ graphregion(color(gs16)) ylabel(,grid gstyle(dot)) ytitle("") xtitle("") /*
	*/ title("Reserves to Total Assets", size(*0.7)) subtitle("All banks, monthly data") caption("Source: Banque du Liban" "Note: The first vertical line is the announcement date (June 2001)." /*
	*/ "The second vertical line is the implementation date (Oct 2001)." "The rise in 2003 is not the result of changes in required reserves but follows" "the Paris II donor conference.  Its effect is tested in detail in Section 4.")

line D12ln_a_loan D12ln_a_loan_fc D12ln_a_loan_ll date if date <= m(2004m12) & date>=m(1997m12), clwidth(vthick medthick medthick) xline(497)  /*
	*/ legend(region(fcolor(gs16))  lab(1 "Total") lab(2 "Foreign Currency") lab(3 "Lira")) /*
	*/ xlabel(461 479 497 515 533 ,labsize(*0.75)) clcolor(edkblue gs0 erose)  /*
	*/ graphregion(color(gs16)) ylabel(,grid gstyle(dot)) ytitle("") xtitle("") /*
	*/ title("Lending Growth, year-on-year", size(*0.7)) subtitle("All banks, monthly data") caption("Source: Banque du Liban" "Note: The vertical line is the announcement date.")
	

/*
**************************
*To include in Table on macro variables (see descriptive statistics generated at end of code below)
**************************	
gen bdl_total = abdl_gold+abdl_fa+abdl_otherfa+abdl_private+abdl_bank+abdl_public+abdl_securities+abdl_fix+abdl_other
gen bdl_fatoa = abdl_fa/bdl_total
gen bdl_sectoa = abdl_securities/bdl_total
gen bdl_fatocurrency = abdl_fa/lbdl_currency
gen bdl_bankreservetoa = lbdl_bank/bdl_total

foreach x in bdl_fatoa bdl_fatocurrency bdl_bankreservetoa {
	egen mean`x' = mean(`x'), by(year)
}
br year mean* bdl_fatoa bdl_fatocurrency bdl_bankreservetoa  if month == 12


*If want to extract quarterly averages:
gen quarter = 1 if month == 1 | month == 2 | month == 3
replace quarter = 2 if month == 4 | month == 5 | month == 6
replace quarter = 3 if month == 7 | month == 8 | month == 9
replace quarter = 4 if month == 10 | month == 11 | month == 12
gen qdate = yq(year,quarter)
format qdate %tq
*Create series proxying excess reserves (unfortunately BDL only reports total actual bank reserves, no split by currency):
gen a_exc_reserve = a_reserve - (0.13*l_deposit_sight) - (0.13*l_deposit_timesaving_ll) if date <= tm(2001m9)
replace a_exc_reserve = a_reserve - (0.25*l_deposit_sight) - (0.15*l_deposit_timesaving_ll) - (0.15*l_deposit_fc) if date >= tm(2001m10)
gen excrtoa = a_exc_reserve/a_total
gen bdl_excrtoa = a_exc_reserve/bdl_total
foreach x of varlist bdl_total bdl_fatoa bdl_sectoa bdl_bankreservetoa bdl_excrtoa reserve_toa excrtoa lbdl_bank {
	egen avq_`x' = mean(`x'), by(qdate)
}
br qdate avq_* if qdate ~= qdate[_n-1]



*/
