set more off
*note change directory below according to location of input files
cd "H:\Reserve Requirement\Stata\FinalJMCB_MS11_463"


**************************************************
*First begin by creating macro variables
do macro
**************************************************

*Back to main bilan banques data set
insheet using bilan.csv

gen str2 temp = substr(code,2,2)
gen id = real(temp)
drop temp
tsset id year
order id year code name

**************************************************
*Merging with macro..
*Note that macrotemp is the output of running the program macro.do
**************************************************
sort year
merge year using macrotemp.dta
sort id year
*Dropping years 1994 & 1995 (not available in bank-level analysis)
drop if _merge == 2
drop _merge
erase macrotemp.dta

**************************************************
*First dealing with units
**************************************************
*Balance sheet items were mostly input in USD million
*For the exchange rate used by Bilanbanques, see series
*from macro dataset: bb_erate to calculate the item in LL mn.

*Only the following items were input in units different from USD mn:
*In %: a_share_ll , l_share_ll, netliqasset_to_deposit, netliqasset_to_deposit_ll, and rar_bis
*In count: branches, staff
*See code later below before I call mergers.do that converts from % to values
*Also some values in LL million: some items about average interest earnings and interest paid (only reported in LL mn).
*So for consistency with units of b.s. items, will convert these to USD mn:

*Note double-check that interestexp_ll + interestexp_fc = pl_interestexp
*And interestinc_ll + interestinc_fc = pl_interestinc
*Discovered some input mistakes by RAs in the process:
replace interestexp_ll = interestexp_ll/1000 if id == 4 & year == 1999
replace interestexp_fc = interestexp_fc/10 if id == 9 & year == 1999
replace interestexp_fc = interestexp_fc*10 if id == 18 & year == 1999
replace interestexp_fc = interestexp_fc/1000 if id == 21 & year == 1999
replace interestexp_ll = interestexp_ll/1000 if id == 34 & year == 1998
replace interestexp_ll = interestexp_ll/10 if id == 43 & year == 2001
replace interestinc_fc = interestinc_fc/1000 if id == 47 & year == 1999
replace interestinc_fc = interestinc_fc/10 if id == 6 & year == 2000


foreach x in av_assetwithint_ll av_assetwithint_fc interestexp_ll interestexp_fc /*
	*/ interestinc_ll interestinc_fc {
	replace `x' = `x'/bb_erate
}

**************************************************
*Second dealing with spurious zeros etc.
**************************************************
replace a_total = . if a_total == 0
foreach x in a_reserve a_tbill a_bondfix a_bondvar a_bank a_affiliate_deposit   /*
	*/ a_loan a_loan_ci a_loan_customer a_loan_overdraft a_loan_sub 		  /*
	*/ a_loan_subunrealisedr a_loan_netaccount a_loan_related a_loan_doubt    /*
	*/ a_bankacceptance a_affiliate_investloan a_affiliate_investequity 	  /*
	*/ a_fix_tangible a_fix_intangible a_other a_regularisation a_revaluation /*
	*/ a_goodwill a_provision_doubt a_contra		 				  /*	
	*/ l_bdl l_bank l_affiliate_deposit l_deposit l_deposit_sight 		  /*
	*/ l_deposit_time l_deposit_saving l_deposit_netaccount l_deposit_related /*
	*/ l_otherfin l_capital l_equity l_ltdebt l_subdebt l_total l_contra 	{
	replace `x' = . if a_total == .
}
*For most balance sheet items, we can also replace with a 0 if the item is missing
*but a_total is different from 0. 
*But I will NOT do this with doubtful loans or footnote items like substandard loans
*because it would further bias the already under-reported poor performing loans
*And also will not adjust the contra accounts which are off balance sheet (?)
foreach x in a_reserve a_tbill a_bondfix a_bondvar a_bank a_affiliate_deposit   /*
	*/ a_loan a_loan_ci a_loan_customer a_loan_overdraft         		  /*
	*/ a_loan_netaccount a_loan_related         					  /*
	*/ a_bankacceptance a_affiliate_investloan a_affiliate_investequity 	  /*
	*/ a_fix_tangible a_fix_intangible a_other a_regularisation a_revaluation /*
	*/ a_goodwill			 						 	  /*	
	*/ l_bdl l_bank l_affiliate_deposit l_deposit l_deposit_sight 		  /*
	*/ l_deposit_time l_deposit_saving l_deposit_netaccount l_deposit_related /*
	*/ l_otherfin l_capital l_equity l_ltdebt l_subdebt l_total  	{
	replace `x' = 0 if `x' == . & a_total ~= .
}

foreach x in l_deposit a_loan l_bdl l_bank l_affiliate_deposit /*
	*/ a_reserve a_tbill a_bondfix a_bondvar a_bank a_affiliate_deposit {
	replace `x'_fc = . if `x'_ll == .
}

*Net profits and net interest income are derived as residuals of some items on P/L section
*But if all these items are missing, then replace the net profit and interest terms with missing
*to avoid a spurious zero (indeed, most likely they are negative b/c banks did not report P/L)
replace pl_interestnet = . if pl_interestinc == . & pl_interestexp ==. & pl_provision == .
replace pl_profitnet_aftertax = . if pl_incomenet_beforetax == . & /*
	*/  pl_incomeextra_beforetax == . & pl_incometax ==. & pl_affiliate_investequity == .

**************************************************
*Accounting for Mergers
**************************************************

*To be able to sum accounting data when merging 2 banks, can't use ratios, so convert 4 series reported as share from % to values
*Note: difficult to deal with rar_bis (risk-based capital ratio), so keep as is

gen a_total_ll = (a_share_ll/100)*a_total
gen l_total_ll = (l_share_ll/100)*l_total
gen netliqasset = (netliqasset_to_deposit/100)*l_deposit 
gen netliqasset_ll = (netliqasset_to_deposit_ll/100)*l_deposit_ll
drop a_share_ll l_share_ll netliqasset_to_deposit netliqasset_to_deposit_ll

*Note as it is written now, mergers.do force-merges to create a pre-merged unique bank and drops the target
*	e.g. when ABN Amro was acquired by Byblos in 2002, Byblos data is overwritten to include ABN Amro prior to 2002, and ABN is then dropped
do mergers
sort id year

**************************************************
*Creating Variables 
**************************************************

*To avoid using all-banks balance sheet in panel (id = 1 is consolidated all banks)
drop if id == 1

*TIME DUMMIES OF INTEREST
*E.g., to test robustness to 2003 large increase in voluntary (excess) reserves by banks as well as other placebo regressions
foreach x in 96 97 98 99 00 01 02 03 04 {
	gen D`x' = 0
	replace D`x' = 1 if year == 19`x'
	replace D`x' = 1 if year == 20`x'
}
gen D0102 = D01
replace D0102 = 1 if year == 2002
gen D9798 = 0
replace D9798 = 1 if year == 1997 | year == 1998
gen D9900 = 0
replace D9900 = 1 if year == 1999 | year == 2000
gen D0304 = 0
replace D0304 = 1 if year == 2003 | year == 2004


*SIZE
*BIG DUMMY (in the upper 85th percentile of fraction of real system assets over 1996-2004 period)
*Setting US CPI index to 1 in 1996 (for summary stats table to get real assets in 1996 USD million)
egen temp1 = mean(fred_uscpi) if year == 1996
egen temp = mean(temp1)
replace fred_uscpi = fred_uscpi/temp 
drop temp*
gen rassets = a_total/fred_uscpi
by id: egen mrassets = mean(rassets)
egen tempaggrassets = sum(mrassets), by(year)
egen aggrassets = mean(tempaggrassets)
gen fracassets = mrassets/aggrassets
pctile pct = fracassets, nq(20)
gen big = 0
replace big = 1 if fracassets >= pct[17]
*Get the 10 banks: BLOM, Byblos, Audi,Medit, BoB, Libano-Francaise, Credit Lib, Fransabank, SGBL, and BBAC 
*	note: Only 2 of these are foreign (Libano-Francaise and SGBL) and even so not fully foreign owned
drop mrassets *aggrassets fracassets pct
*OTHER SIZE (ASSETS / STAFF / BRANCHES)
foreach x in a_total staff branches {
	gen ln_`x' = log(`x')
}

*FOREIGN OWNERSHIP AND DATE OF ESTABLISHMENT
*	Can add more characteristics later on (this is based on file: Alice bank characteristics)
*	Also can use Roy's Kompass inputs
do banktype
gen Dage_prewar = 0
replace Dage_prewar = 1 if date_estab <= 1975
*note that latest date_estab was 2003 in sample (and oldest is 1876)
gen age = 2004-date_estab
gen lnage = ln(age)

* PROXIES FOR TOTAL CURRENT LOANS AND FOR NON-PERFORMING LOANS
*	(removes doubtful & substandard. And in case of curloan2, also removes overdrafts, net accounts & related parties loans )
gen a_curloan = a_loan_ci + a_loan_customer + a_loan_overdraft + a_loan_netaccount + a_loan_related - a_loan_sub
replace a_curloan = a_loan_ci + a_loan_customer + a_loan_overdraft + a_loan_netaccount + a_loan_related  if a_loan_sub == .
gen a_curloan2 = a_loan_ci + a_loan_customer - a_loan_sub
replace a_curloan2 = a_loan_ci + a_loan_customer if a_loan_sub == .
gen a_npl = a_loan_doubt + a_loan_sub
replace a_npl = a_loan_doubt if a_loan_sub == .
replace a_npl = a_loan_sub if a_loan_doubt == .


*LIQUID ASSETS
*	measured by ratio of securities to assets (as in Kashyap and Stein 2000)
*		(do not include cash and CB b/c of required reserves, similar to KS argument)
* 	but can try as alternative with reserves (a_liq2)
gen a_liq = a_tbill + a_bondfix + a_bondvar 
gen a_liq2 = a_liq + a_reserve
foreach x in ll fc {
	gen a_liq_`x' = a_tbill_`x' + a_bondfix_`x' + a_bondvar_`x'
	replace a_liq_`x' = a_tbill_`x' + a_bondfix_`x' if a_bondvar_`x' == .
	replace a_liq_`x' = a_tbill_`x' + a_bondvar_`x' if a_bondfix_`x' == .
	replace a_liq_`x' = a_bondfix_`x' + a_bondvar_`x' if a_tbill_`x' == .
	replace a_liq_`x' = a_bondfix_`x' if a_tbill_`x' ==.  & a_bondvar_`x' == .
	replace a_liq_`x' = a_tbill_`x' if a_bondfix_`x' == . & a_bondvar_`x' == .
	replace a_liq_`x' = a_bondvar_`x' if a_bondfix_`x' ==. & a_tbill_`x' == .	
	gen a_liq2_`x' = a_liq_`x' + a_reserve_`x'
	replace a_liq2_`x' = a_liq_`x' if a_liq2_`x' == . 
}
*adjusting a_liq2_fc for 2001 onwards (when not all fc resreves were excess)
gen a_liq2adj_fc = a_liq2_fc 
replace a_liq2adj_fc = a_liq2_fc - 0.15*(l_deposit_fc) if year >= 2001 & a_reserve_fc ~=.


*LOAN , LIQUID, RESERVE AND DEPOSIT GROWTH 
*Also following comment by Referee - allow for additional margins of adjustment such as non-deposit funding changes..
gen l_bankbdl = l_bank + l_bdl
gen l_netbank = l_bank - a_bank
gen l_netaffiliate = l_affiliate_deposit - a_affiliate_deposit 
gen l_debt = l_subdebt + l_ltdebt
gen l_wholesale = l_bank + l_bdl + l_subdebt + l_ltdebt
gen l_other = l_affiliate_deposit + l_otherfin
gen a_affiliate_invest = a_affiliate_investloan + a_affiliate_investequity
foreach x in a_loan a_loan_ci a_loan_customer a_loan_ll a_loan_fc a_curloan a_curloan2 /*
	*/ a_liq a_liq_ll a_liq_fc a_liq2 a_liq2_ll a_liq2_fc a_liq2adj_fc a_reserve a_reserve_ll a_reserve_fc   /*
	*/ a_bank a_affiliate_deposit a_bankacceptance a_affiliate_invest /*
	*/ l_deposit l_deposit_ll l_deposit_fc  /*
	*/ l_bdl l_bank l_bankbdl l_netbank l_ltdebt l_subdebt l_debt l_wholesale l_affiliate_deposit l_netaffiliate l_otherfin l_other l_capital l_equity /* 
	*/	{
	gen ln_`x' = log(`x')
	gen Dln_`x' = D.ln_`x'
	gen Dtoa_`x' = D.`x'/L.a_total
	drop ln_`x'
}

*REAL GROWTH OF BALANCE SHEET ITEMS (for robustness - but doesn't matter)
*In 1996 LL, 1996 USD respectively
*Setting US CPI index to 1 in 1996 (already done above for size calc)
*Setting Lebanon CPI index to 1 in 1996 (it's already 100 in 1996)
replace imf_cpi = imf_cpi/100
*And setting exchange rate index = 1 in 1996 
egen temp1 = mean(bb_erate) if year == 1996
egen temp = mean(temp1)
gen bb_index_erate = bb_erate/temp 
drop temp1 temp
*Now for real conversions to 1996
foreach x in a_total a_loan a_loan_ci a_curloan a_curloan2 a_liq a_liq2 a_reserve l_deposit {
	gen `x'_r = `x'/fred_uscpi
	gen ln_`x'_r = log(`x'_r)
	gen Dln_`x'_r = D.ln_`x'_r
}
foreach x in a_loan_fc a_liq_fc a_liq2_fc a_reserve_fc l_deposit_fc		{
	gen `x'_r = `x'/fred_uscpi
	gen ln_`x'_r = log(`x'_r)
	gen Dln_`x'_r = D.ln_`x'_r
}
foreach x in a_loan_ll a_liq_ll a_liq2_ll a_reserve_ll  l_deposit_ll  	{
	gen `x'_r = bb_index_erate*`x'/imf_cpi 
	gen ln_`x'_r = log(`x'_r)
	gen Dln_`x'_r = D.ln_`x'_r
}

* LL SHARES (Note: main variable in regressions "LCD" is l_deposit_share_ll)
gen l_deposit_share_ll = l_deposit_ll/l_deposit
gen a_loan_share_ll = a_loan_ll/a_loan
gen a_share_ll = a_total_ll/a_total
gen l_share_ll = l_total_ll/l_total


*CONTROLS
*Note capital is made of equity + lt debt + subordinated debt
gen loantoa = a_loan/a_total
gen curloantoa = a_curloan/a_total
gen captoa = l_capital/a_total
gen eqtoa = l_equity/a_total
replace rar_bis = rar_bis/100
gen npltol = a_npl/a_loan
gen liqtoa = a_liq/a_total
gen liqlltoa = a_liq_ll/a_total
gen liqfctoa = a_liq_fc/a_total
gen liq2toa = a_liq2/a_total
gen liq2lltoa = a_liq2_ll/a_total
gen liq2fctoa = a_liq2_fc/a_total
gen liq2adjfctoa = a_liq2adj_fc/a_total 
gen reservefctoa = a_reserve_fc/a_total
replace reservefctoa = (a_reserve_fc - 0.15*l_deposit_fc)/a_total if year >= 2001
gen netliqtoa = netliqasset/a_total
gen netliqfctoa = (netliqasset-netliqasset_ll)/a_total
gen provtoa = a_provision_doubt/a_total
gen roa = pl_profitnet_aftertax/a_total
gen roe = pl_profitnet_aftertax/l_equity
gen wholesaletoa = (l_bank + l_bdl)/a_total
gen wholesale2toa = (l_bank)/a_total
gen wholesalefctoa = (l_bank_fc + l_bdl_fc)/a_total
replace wholesalefctoa = (l_bank_fc)/a_total if l_bdl_fc == .
gen wholesale2fctoa = (l_bank_fc)/a_total
gen borrowafftoa = l_affiliate_deposit/a_total 
gen borrowothertoa = l_otherfin/a_total 
gen iloan = pl_interestinc_loan/a_loan
gen idep =  pl_interestexp_deposit/l_deposit
gen imargin1 = iloan - idep
gen imargin2 = (pl_interestinc-pl_interestexp)/(av_assetwithint_ll+av_assetwithint_fc)
gen imargin2_ll = (interestinc_ll - interestexp_ll)/av_assetwithint_ll
gen imargin2_fc = (interestinc_fc - interestexp_fc)/av_assetwithint_fc
*Reserve Ratio (really cash and central bank, and banks do hold excess reserves)
*	but idea is that those with a higher ratio relative to others should be less constrained
*	and in particular those with a higher FC reserve ratio 
gen a_rr = a_reserve/l_deposit
foreach x in ll fc {
	gen a_rr_`x' = a_reserve_`x'/l_deposit_`x'
}
*And proxy for excess reserves (because required reserves on ll depends on what share is sight vs time but divisions are only
*	reported for total deposits so proxy is 0.94*0.15+0.06*0.25 b/c roughly 94% of ll deposits in BDL fall under term
gen a_excrr_fc = a_rr_fc if year < 2001
replace a_excrr_fc = a_rr_fc - 0.15 if year >= 2001
gen a_excrr_ll = a_rr_ll -0.13 if year < 2001
replace a_excrr_ll = a_rr_ll -0.156 if year >= 2001 

*LAGS
foreach x in ln_a_total ln_staff ln_branches 			      	    /*
	*/ l_deposit_share_ll a_loan_share_ll a_share_ll l_share_ll           /*
	*/ captoa eqtoa rar_bis npltol liqtoa liqlltoa liqfctoa liq2toa liq2lltoa liq2fctoa liq2adjfctoa reservefctoa netliqtoa netliqfctoa /*
	*/ provtoa roa roe imargin1 imargin2 imargin2_ll imargin2_fc wholesaletoa wholesale2toa wholesalefctoa wholesale2fctoa borrowafftoa borrowothertoa  /*
	*/ a_rr a_rr_ll a_rr_fc loantoa  {
	gen L_`x' = L.`x'
}



*INTERACTIONS ETC
*Where the `x' are the shocks and the `y' are (first lag) bank characteristics
*due to name length restrictions in Stata, shorten:
rename Dmaxinterbank Dmaxibank
rename LDmaxinterbank LDmaxibank

foreach x in D01 D02 D0102 D03 D00 D9798 D9900 D0304 /*
	*/ growth Dlncoindex Dinterbank Dmaxibank Dtb3m Dlnbdl_m1 Dlnbdl_m2 Dlnbdl_m3 Dlnbdl_fa Dusffunds Dssprd /*
	*/ Lgrowth LDlncoindex LDinterbank LDmaxibank LDtb3m LDlnbdl_m1 LDlnbdl_m2 LDlnbdl_m3 LDlnbdl_fa LDusffunds LDssprd {
	foreach y in  L_l_deposit_share_ll  L_l_share_ll L_a_loan_share_ll L_a_share_ll L_loantoa /*
		*/  L_liqtoa L_liqlltoa L_liqfctoa L_liq2toa L_liq2lltoa L_liq2fctoa L_liq2adjfctoa L_reservefctoa L_netliqtoa L_netliqfctoa /*
		*/ L_roa L_roe L_captoa L_eqtoa L_rar_bis L_npltol L_provtoa /*
		*/ L_imargin1 L_imargin2 L_imargin2_ll L_imargin2_fc /*
		*/ L_a_rr L_a_rr_ll L_a_rr_fc loantoa L_wholesaletoa L_wholesale2toa L_wholesalefctoa L_wholesale2fctoa L_borrowafftoa L_borrowothertoa /*
		*/ big L_ln_a_total Dage_prewar lnage foreign foreign_arab foreign_west    { 
		gen `x'X`y' = `x'*`y'
	}
}

*OUTLIERS - 
*to estimate after trimming upper and lower 2.5 percent of dependent variable
foreach x in a_loan a_loan_ci a_loan_customer a_loan_ll a_loan_fc a_curloan a_curloan2 /*
	*/ a_liq a_liq_ll a_liq_fc a_liq2 a_liq2_ll a_liq2_fc a_liq2adj_fc a_reserve a_reserve_ll a_reserve_fc   /*
	*/ a_bank a_affiliate_deposit a_bankacceptance a_affiliate_invest /*
	*/ l_deposit l_deposit_ll l_deposit_fc  /*
	*/ l_bdl l_bank l_bankbdl l_netbank l_ltdebt l_subdebt l_debt l_wholesale l_affiliate_deposit l_netaffiliate l_otherfin l_other l_capital l_equity /* 
	*/	{
	sort Dln_`x'
	pctile pct = Dln_`x', nq(200)
	gen out_Dln_`x' = 1 if Dln_`x' >= pct[195] & Dln_`x' ~=.
	replace out_Dln_`x' = 1 if Dln_`x' <= pct[5] & Dln_`x' ~=.
	drop pct
	sort Dtoa_`x'
	pctile pct = Dtoa_`x', nq(200)
	gen out_Dtoa_`x' = 1 if Dtoa_`x' >= pct[195] & Dtoa_`x' ~=.
	replace out_Dtoa_`x' = 1 if Dtoa_`x' <= pct[5] & Dtoa_`x' ~=.
	drop pct
}
	

sort id year


/*
****************************************
*Summary Descriptive Tables (with July 2012 update)
****************************************

*First getting some summary stats for macro indicators to combine with BDL foreign assets tabulated from bdl.dta to create Table 1
br year growth Dlncoindex interbank ssprd Dlnbdl_m1-Dlnbdl_m3 if id ==3

egen n_banks = count(id) , by(year foreign)
*To get real assets so that in 1996 USD mn (already assigned earlier when assigning big bank dummy)
egen mrassets = mean(rassets), by(year foreign)
egen medrassets = median(rassets), by(year foreign)
egen aggrassets = sum(rassets), by(year)
egen aassets = sum(rassets), by(year foreign)
gen fracassets = aassets/aggrassets

*For all years average
sort id year 
gen flagunique = 1 if id ~= id[_n-1]
egen nall_banks = count(flagunique) , by(foreign)
egen temp1 = mean(rassets), by(foreign)
egen temp2 = median(rassets), by(foreign)
egen temp3 = sum(rassets)
egen temp4 = sum(rassets), by(foreign)
gen temp5 = temp4/temp3

*Creating fractions of total assets for descriptive table (Table A1)
*First, some series will be aggregated (like time and saving deposits)
gen l_deposit_ts = l_deposit_time + l_deposit_saving
foreach x in ll fc {
	gen l_bankbdl_`x' = l_bank_`x' + l_bdl_`x' 
	replace l_bankbdl_`x' = l_bank_`x' if l_bdl_`x' == .
	replace l_bankbdl_`x' = l_bdl_`x' if l_bank_`x' ==.
}
foreach x in a_reserve a_reserve_fc a_reserve_ll a_liq a_liq_fc a_liq_ll 		/*
	*/ a_bank a_bank_fc a_bank_ll a_loan a_loan_fc a_loan_ll a_curloan a_curloan2 a_loan_ci /*
	*/ l_deposit l_deposit_fc l_deposit_ll l_deposit_sight l_deposit_ts  		/*
	*/ l_bank l_bdl l_bankbdl l_bankbdl_fc l_bankbdl_ll l_other l_affiliate_deposit l_otherfin l_debt l_equity {
	gen `x'_toa = `x'/a_total
	egen av1_`x'_toa = mean(`x'_toa), by(year foreign)
	egen avall_`x'_toa = mean(`x'_toa), by(foreign)
}
foreach x in a_loan_share_ll l_deposit_share_ll a_share_ll l_share_ll /*
	*/ npltol provtoa netliqtoa roa roe iloan idep imargin1 imargin2 imargin2_ll imargin2_fc rar_bis {
	egen av1_`x' = mean(`x'), by(year foreign)
	egen avall_`x' = mean(`x'), by(foreign)
}
*And if want to know whether each bank matches its share of LL liab to assets 
* (not just average above, which results in roughly 45% of assets/liab in LL for domestic banks, and 30% for foreign banks.
gen diff_al_share_ll = a_share_ll - l_share_ll
foreach x in diff_al_share_ll {
	egen av1_`x' = mean(`x'), by(year foreign)
	egen avall_`x' = mean(`x'), by(foreign) 
	egen sd1_`x' = sd(`x'), by(year foreign)
	egen sdall_`x' = sd(`x'), by(foreign)
}
	
*Viewing for foreign (e.g. id=3) and domestic banks (e.g. id=4), respectively 
br year foreign n_banks mrassets medrassets fracassets nall_banks temp1 temp2 temp5 av1* avall* if id == 3 | id == 4


*July 2012 -- Updating Descriptive Statistics to Provide More Complete Table:
tabstat Dln_a_curloan loantoa curloantoa a_loan_share_ll l_deposit_share_ll a_share_ll l_share_ll diff_al_share_ll /*
	*/ a_rr a_rr_ll a_rr_fc a_excrr_ll a_excrr_fc /*
	*/ liqfctoa liq2fctoa liq2adjfctoa eqtoa ln_a_total /* 
	*/ rar_bis roa wholesale2toa liqtoa netliqtoa provtoa npltol  /*
	*/ iloan idep imargin1 imargin2 imargin2_ll imargin2_fc /*
	*/   , stats(mean sd p25 p50 p75 count) by(foreign)
tabstat Dln_a_curloan if out_Dln_a_curloan ~=1 , stats(mean sd p25 p50 p75 count) 

*excess reserve distribution over time (remember for ll, it is only an estimate b/c Bilanbanques does not split ll by time/sight)
tabstat a_rr a_rr_ll a_rr_fc a_excrr_ll a_excrr_fc if year == 2000, stats(mean sd p25 p50 p75 count) by(foreign)
tabstat a_rr a_rr_ll a_rr_fc a_excrr_ll a_excrr_fc if year == 2001, stats(mean sd p25 p50 p75 count) by(foreign)
tabstat a_rr a_rr_ll a_rr_fc a_excrr_ll a_excrr_fc if year == 2002, stats(mean sd p25 p50 p75 count) by(foreign)
tabstat a_rr a_rr_ll a_rr_fc a_excrr_ll a_excrr_fc if year == 2003, stats(mean sd p25 p50 p75 count) by(foreign)
*alternatively if want to tabulate excess reserves scaled by total assets:
gen a_excrtoa_ll = a_excrr_ll*(l_deposit_ll/a_total)
gen a_excrtoa_fc = a_excrr_fc*(l_deposit_fc/a_total)
tabstat a_excrtoa_ll a_excrtoa_fc if year == 2000, stats(mean sd p25 p50 p75 count) by(foreign)
tabstat a_excrtoa_ll a_excrtoa_fc if year == 2001, stats(mean sd p25 p50 p75 count) by(foreign)
tabstat a_excrtoa_ll a_excrtoa_fc if year == 2002, stats(mean sd p25 p50 p75 count) by(foreign)
tabstat a_excrtoa_ll a_excrtoa_fc if year == 2003, stats(mean sd p25 p50 p75 count) by(foreign)

*/



/*

****************************************
*REGRESSIONS
****************************************
*log using bilanlog_july2012.log, replace


*Table 3(2)
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

*Just Average 2001 effect:
*Table 3(1)
xtreg Dln_a_curloan D01 /*
	*/ if out_Dln_a_curloan  ~= 1  , fe cluster(id)
xtreg Dln_a_curloan D0102 /*
	*/ if out_Dln_a_curloan  ~= 1  , fe cluster(id)


*Testing Below/Above median pre-announcement FC reserves (some banks are missing 2000 so also average over 99/00)
drop temp*
egen temp = mean(a_rr_fc) if year == 1999 | year == 2000, by(id)
egen temp2 = mean(temp), by(id)
tabstat a_rr_fc if year == 1999 | year == 2000, stats(p50) save
matrix define A = r(StatTotal)
gen low = 1 if temp2 < A[1,1]  
replace low = 0 if temp2 >= A[1,1] & temp2 ~=. 
drop temp temp2

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 & low == 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 & low == 0 , fe cluster(id)


*Domestic/Foreign
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 & foreign == 0 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 & foreign == 1 , fe cluster(id)

*And Testing Domestic/Foreign differences
gen interact_foreign = D01Xforeign*L_l_deposit_share_ll
gen interact2_foreign = D01Xforeign*L_liqfctoa
gen foreignXL_l_deposit_share_ll = foreign*L_l_deposit_share_ll
gen foreignXL_liqfctoa = foreign*L_liqfctoa

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa /*
	*/ foreign interact_foreign interact2_foreign /*
	*/ D01Xforeign foreignXL_l_deposit_share_ll foreignXL_liqfctoa /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/  L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)






*With 2002


xtreg Dln_a_curloan L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 & foreign == 0 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 & foreign == 1 , fe cluster(id)

*Testing sensitivity differences
drop interact* 
gen interact_foreign = D0102Xforeign*L_l_deposit_share_ll
gen interact2_foreign = D0102Xforeign*L_liqfctoa
xtreg Dln_a_curloan L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa /*
	*/ foreign interact_foreign interact2_foreign /*
	*/ D0102Xforeign foreignXL_l_deposit_share_ll foreignXL_liqfctoa /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/  L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)
test D0102XL_l_deposit_share_ll + interact_foreign = 0
test D0102XL_liqfctoa + interact2_foreign = 0


xtreg Dln_l_otherfin L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_l_otherfin  ~= 1 & foreign == 1 , fe cluster(id)

xtreg Dln_l_otherfin L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_l_otherfin  ~= 1 & foreign == 0 , fe cluster(id)

xtreg Dln_l_affiliate_deposit L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_l_affiliate_deposit  ~= 1 & foreign == 1 , fe cluster(id)

xtreg Dln_l_affiliate_deposit L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ if out_Dln_l_affiliate_deposit  ~= 1 & foreign == 1 , fe cluster(id)

xtreg Dln_l_affiliate_deposit L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_l_affiliate_deposit  ~= 1 & foreign == 0 , fe cluster(id)

xtreg Dln_a_affiliate_invest L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_affiliate_invest ~= 1 & foreign == 1 , fe cluster(id)

xtreg Dln_a_affiliate_invest L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_affiliate_invest ~= 1 & foreign == 0 , fe cluster(id)

*not enough obs for foreign for l_debt :
xtreg Dln_l_debt L_l_deposit_share_ll D0102 D0102XL_l_deposit_share_ll /*
	*/ L_liqfctoa D0102XL_liqfctoa  /*
	*/ L_eqtoa D0102XL_eqtoa   /*
	*/ L_ln_a_total D0102XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_l_debt ~= 1 & foreign == 0 , fe cluster(id)


*Robustness checks
*Table A2

xtreg Dln_a_curloan D01 D01Xforeign /*
	*/ if out_Dln_a_curloan  ~= 1  , fe cluster(id)
reg Dln_a_curloan D01 D01Xforeign /*
	*/ if out_Dln_a_curloan  ~= 1  , cluster(id)
xtreg Dln_a_curloan D0102 D0102Xforeign /*
	*/ if out_Dln_a_curloan  ~= 1  , fe cluster(id)
reg Dln_a_curloan D0102 D0102Xforeign /*
	*/ if out_Dln_a_curloan  ~= 1  , cluster(id)

*Table 3(2) with No fixed effects
reg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 ,  cluster(id)

*Table 3(2) with FE + All Year effects
xtreg Dln_a_curloan L_l_deposit_share_ll D97-D04 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ /*LDinterbank*/ LDinterbankXL_l_deposit_share_ll  /*
	*/ /*LDlncoindex*/ LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


*Other bank controls
*Table A3 and more

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liq2fctoa D01XL_liq2fctoa /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liq2adjfctoa D01XL_liq2adjfctoa /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_liq2toa  D01XL_liq2toa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_netliqtoa D01XL_netliqtoa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_a_loan_share_ll D01XL_a_loan_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_loantoa D01XL_loantoa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


*alternative risk-based capital ratio

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ /*L_eqtoa D01XL_eqtoa*/   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_rar_bis D01XL_rar_bis  /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_wholesale2toa D01XL_wholesale2toa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_wholesale2fctoa D01XL_wholesale2fctoa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_borrowafftoa D01XL_borrowafftoa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

*Profitability + Wholesale:
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_roa D01XL_roa  /*
	*/ L_wholesale2toa D01XL_wholesale2toa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ L_roa D01XL_roa  /*
	*/ L_wholesale2toa D01XL_wholesale2toa /*
	*/ L_rar_bis D01XL_rar_bis  /*
	*/ L_provtoa D01XL_provtoa /*
	*/ L_netliqtoa D01XL_netliqtoa /*
	*/ L_loantoa D01XL_loantoa /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


*Other macro controls

*If no interaction of macro variables with LCD:
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank /*LDinterbankXL_l_deposit_share_ll*/  /*
	*/ LDlncoindex /*LDlncoindexXL_l_deposit_share_ll*/  /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

*alternative economic activity measure (IMF growth estimate)
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ /*LDlncoindex LDlncoindexXL_l_deposit_share_ll*/ /*
	*/ Lgrowth LgrowthXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ LDlnbdl_fa LDlnbdl_faXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liq2fctoa D01XL_liq2fctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ LDlnbdl_fa LDlnbdl_faXL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ LDlnbdl_m2 LDlnbdl_m2XL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ LDlnbdl_m3 LDlnbdl_m3XL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ /*LDinterbank LDinterbankXL_l_deposit_share_ll*/  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ LDlnbdl_m3 LDlnbdl_m3XL_l_deposit_share_ll /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

*Paris II 
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ D03 D03XL_l_deposit_share_ll D03XL_liqfctoa D03XL_eqtoa D03XL_ln_a_total /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liq2fctoa D01XL_liq2fctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ D03 D03XL_l_deposit_share_ll D03XL_liqfctoa D03XL_eqtoa D03XL_ln_a_total /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)

*other placebo periods
xtreg Dln_a_curloan L_l_deposit_share_ll D01 D01XL_l_deposit_share_ll /*
	*/ L_liqfctoa D01XL_liqfctoa  /*
	*/ L_eqtoa D01XL_eqtoa   /*
	*/ L_ln_a_total D01XL_ln_a_total /*
	*/ LDinterbank LDinterbankXL_l_deposit_share_ll  /*
	*/ LDlncoindex LDlncoindexXL_l_deposit_share_ll /*
	*/ D9798 D9798XL_l_deposit_share_ll D9798XL_liqfctoa D9798XL_eqtoa D9798XL_ln_a_total /*
	*/ D9900 D9900XL_l_deposit_share_ll D9900XL_liqfctoa D9900XL_eqtoa D9900XL_ln_a_total /*
	*/ D0304 D0304XL_l_deposit_share_ll D0304XL_liqfctoa D0304XL_eqtoa D0304XL_ln_a_total /*
	*/ if out_Dln_a_curloan  ~= 1 , fe cluster(id)


log close

*/